# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [1.1.2] - 2025-11-17

### Changed

* Update the data analysis schema in static files.
* Change the help page from reborn to Loom.
* Change the repository URL from orkg to Loom.
* Move coverage tests from GitHub plus Coveralls to GitLab CICD.
* Change the maintainer.


## [1.1.1] - 2025-02-15

### Changed

* Unit tests mock the ORKG and ePIC API access.

## [1.1.0] - 2024-12-07

### Added

* Allow schemata with flexibly selected parts.

### Changed

* Update static files.
* Update schemata for unit tests.

## [1.0.0] - 2024-09-14

### Added

* Initial release

Exported functions: load_datatype() and to_jsonld()

[unreleased]: https://gitlab.com/TIBHannover/lki/knowledge-loom/dtreg-python/-/compare/v1.1.2...master
[1.1.2]: https://gitlab.com/TIBHannover/lki/knowledge-loom/dtreg-python/-/compare/v1.1.1...v1.1.2
[1.1.1]: https://gitlab.com/TIBHannover/lki/knowledge-loom/dtreg-python/-/compare/v1.1.0...v1.1.1
[1.1.0]: https://gitlab.com/TIBHannover/lki/knowledge-loom/dtreg-python/-/compare/v1.0.0...v1.1.0
[1.0.0]: https://gitlab.com/TIBHannover/lki/knowledge-loom/dtreg-python/-/tags/v1.0.0